@@ -14,6 +14,7 @@ POP3_ADDR = {
     "126": "pop.126.com",
     "qq": "pop.qq.com",
     "sina": "pop3.sina.com.cn",
+    "88": "pop.88.com",
 }
 
 SMTP_ADDR = {
@@ -27,4 +28,5 @@ SMTP_ADDR = {
     "126": "smtp.126.com",
     "qq": "smtp.qq.com",
     "sina": "smtp.sina.com.cn",
+    "88": "smtp.88.com",
 }
